0.9.9 API documentation: Stable extensions

| 0.9.9 API documentation

- Main Page
- Modules
- Files

Modules
Stable extensions

Additional features not specified by GLSL specification. More...

## Modules
| GLM_EXT_matrix_clip_space
| Defines functions that generate clip space transformation matrices.
| GLM_EXT_matrix_common
| Defines functions for common matrix operations.
| GLM_EXT_matrix_projection
| Functions that generate common projection transformation matrices.
| GLM_EXT_matrix_relational
| Exposes comparison functions for matrix types that take a user defined epsilon values.
| GLM_EXT_matrix_transform
| Defines functions that generate common transformation matrices.
| GLM_EXT_quaternion_common
| Provides common functions for quaternion types.
| GLM_EXT_quaternion_double
| Exposes double-precision floating point quaternion type.
| GLM_EXT_quaternion_double_precision
| Exposes double-precision floating point quaternion type with various precision in term of ULPs.
| GLM_EXT_quaternion_exponential
| Provides exponential functions for quaternion types.
| GLM_EXT_quaternion_float
| Exposes single-precision floating point quaternion type.
| GLM_EXT_quaternion_float_precision
| Exposes single-precision floating point quaternion type with various precision in term of ULPs.
| GLM_EXT_quaternion_geometric
| Provides geometric functions for quaternion types.
| GLM_EXT_quaternion_relational
| Exposes comparison functions for quaternion types that take a user defined epsilon values.
| GLM_EXT_quaternion_transform
| Provides transformation functions for quaternion types.
| GLM_EXT_quaternion_trigonometric
| Provides trigonometric functions for quaternion types.
| GLM_EXT_scalar_common
| Exposes min and max functions for 3 to 4 scalar parameters.
| GLM_EXT_scalar_constants
| Provides a list of constants and precomputed useful values.
| GLM_EXT_scalar_int_sized
| Exposes sized signed integer scalar types.
| GLM_EXT_scalar_integer
| Include <glm/ext/scalar_integer.hpp> to use the features of this extension.
| GLM_EXT_scalar_relational
| Exposes comparison functions for scalar types that take a user defined epsilon values.
| GLM_EXT_scalar_uint_sized
| Exposes sized unsigned integer scalar types.
| GLM_EXT_scalar_ulp
| Allow the measurement of the accuracy of a function against a reference implementation.
| GLM_EXT_vector_bool1
| Exposes bvec1 vector type.
| GLM_EXT_vector_bool1_precision
| Exposes highp_bvec1, mediump_bvec1 and lowp_bvec1 types.
| GLM_EXT_vector_common
| Exposes min and max functions for 3 to 4 vector parameters.
| GLM_EXT_vector_double1
| Exposes double-precision floating point vector type with one component.
| GLM_EXT_vector_double1_precision
| Exposes highp_dvec1, mediump_dvec1 and lowp_dvec1 types.
| GLM_EXT_vector_float1
| Exposes single-precision floating point vector type with one component.
| GLM_EXT_vector_float1_precision
| Exposes highp_vec1, mediump_vec1 and lowp_vec1 types.
| GLM_EXT_vector_int1
| Exposes ivec1 vector type.
| GLM_EXT_vector_int1_precision
| Exposes highp_ivec1, mediump_ivec1 and lowp_ivec1 types.
| GLM_EXT_vector_integer
| Include <glm/ext/vector_integer.hpp> to use the features of this extension.
| GLM_EXT_vector_relational
| Exposes comparison functions for vector types that take a user defined epsilon values.
| GLM_EXT_vector_uint1
| Exposes uvec1 vector type.
| GLM_EXT_vector_uint1_precision
| Exposes highp_uvec1, mediump_uvec1 and lowp_uvec1 types.
| GLM_EXT_vector_ulp
| Allow the measurement of the accuracy of a function against a reference implementation.

## Detailed Description

Additional features not specified by GLSL specification.

EXT extensions are fully tested and documented.

Even if it's highly unrecommended, it's possible to include all the extensions at once by including <glm/ext.hpp>. Otherwise, each extension needs to be included a specific file.